@@ -78,7 +78,7 @@ class SimpleWaypointEnv(gymnasium.Env):
         )
 
         high = np.array([2 * math.pi, 2 * math.pi, 2 * math.pi, 1.0])
-        low = np.array([-2 * math.pi, -2 * math.pi, -2 * math.pi, 0.0])
+        low = np.array([-2 * math.pi, -2 * math.pi, -2 * math.pi, -1.0])
         self.action_space = spaces.Box(low=low, high=high, dtype=np.float64)
 
         """ ENVIRONMENT CONSTANTS """
@@ -139,7 +139,7 @@ class SimpleWaypointEnv(gymnasium.Env):
         thts = self.np_random.uniform(0.0, 2.0 * math.pi, size=(self.num_targets,))
         phis = self.np_random.uniform(0.0, 2.0 * math.pi, size=(self.num_targets,))
         for i, tht, phi in zip(range(self.num_targets), thts, phis):
-            dist = self.np_random.uniform(low=1.0, high=self.flight_dome_size)
+            dist = self.np_random.uniform(low=1.0, high=self.flight_dome_size * 0.9)
             x = dist * math.sin(phi) * math.cos(tht)
             y = dist * math.sin(phi) * math.sin(tht)
             z = abs(dist * math.cos(phi))
@@ -181,7 +181,7 @@ class SimpleWaypointEnv(gymnasium.Env):
         - ang_pos (vector of 3/4 values)
         - lin_vel (vector of 3 values)
         - lin_pos (vector of 3 values)
-        - body_frame distance to target (vector of 3 values)
+        - body_frame distance to target (vector of 3/4 values)
         """
         raw_state = self.env.states[0]
 
@@ -248,7 +248,7 @@ class SimpleWaypointEnv(gymnasium.Env):
             self.truncation = self.truncation or True
 
         # exceed flight dome
-        if np.linalg.norm(self.state[-3:]) > self.flight_dome_size:
+        if np.linalg.norm(self.env.states[0][-1]) > self.flight_dome_size:
             self.reward = -100.0
             self.info["out_of_bounds"] = True
             self.termination = self.termination or True
@@ -269,7 +269,8 @@ class SimpleWaypointEnv(gymnasium.Env):
                     self.yaw_targets = self.yaw_targets[1:]
             else:
                 self.info["env_complete"] = True
-                self.termination = self.termination or True
+                # self.termination = self.termination or True
+                self.truncation = self.truncation or True
 
             # delete the reached target and recolour the others
             if self.enable_render and len(self.target_visual) > 0:
